==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/StochRSIIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { StochRSIIndicatorDescription } from "./StochRSIIndicatorDescription";
/**
 * @hidden
 */
var StochRSIIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StochRSIIndicatorDescriptionMetadata, _super);
    function StochRSIIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StochRSIIndicatorDescriptionMetadata.b = function (a) {
        if (StochRSIIndicatorDescriptionMetadata.a == null) {
            StochRSIIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StochRSIIndicatorDescriptionMetadata.c(StochRSIIndicatorDescriptionMetadata.a);
        }
        if (a.j(StochRSIIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(StochRSIIndicatorDescriptionMetadata.a);
    };
    StochRSIIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    StochRSIIndicatorDescriptionMetadata.d = function (a) {
        StochRSIIndicatorDescriptionMetadata.b(a);
        a.aa("StochRSIIndicator", function () { return new StochRSIIndicatorDescription(); });
        a.z("StochRSIIndicator", StochRSIIndicatorDescriptionMetadata.a);
    };
    StochRSIIndicatorDescriptionMetadata.$t = markType(StochRSIIndicatorDescriptionMetadata, 'StochRSIIndicatorDescriptionMetadata');
    StochRSIIndicatorDescriptionMetadata.a = null;
    return StochRSIIndicatorDescriptionMetadata;
}(Base));
export { StochRSIIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/StochRSIIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { StochRSIIndicatorDescription } from "./StochRSIIndicatorDescription";
/**
 * @hidden
 */
var StochRSIIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StochRSIIndicatorDescriptionMetadata, _super);
    function StochRSIIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StochRSIIndicatorDescriptionMetadata.b = function (a) {
        if (StochRSIIndicatorDescriptionMetadata.a == null) {
            StochRSIIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StochRSIIndicatorDescriptionMetadata.c(StochRSIIndicatorDescriptionMetadata.a);
        }
        if (a.k(StochRSIIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(StochRSIIndicatorDescriptionMetadata.a);
    };
    StochRSIIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    StochRSIIndicatorDescriptionMetadata.d = function (a) {
        StochRSIIndicatorDescriptionMetadata.b(a);
        a.ac("StochRSIIndicator", function () { return new StochRSIIndicatorDescription(); });
        a.ab("StochRSIIndicator", StochRSIIndicatorDescriptionMetadata.a);
    };
    StochRSIIndicatorDescriptionMetadata.$t = markType(StochRSIIndicatorDescriptionMetadata, 'StochRSIIndicatorDescriptionMetadata');
    StochRSIIndicatorDescriptionMetadata.a = null;
    return StochRSIIndicatorDescriptionMetadata;
}(Base));
export { StochRSIIndicatorDescriptionMetadata };
